$fn = 25;
wall_thickness = 3;
basic_tool_radius = 6.1;
base_thickness = 3.5;
//tool_count = 6;
tool_spacing = 2.75;

height = 105;
x_hole_offset = wall_thickness + 1.20;
y_hole_offset = 1.25;
width = basic_tool_radius * 4.2 + x_hole_offset;
depth = 185.5;
tool_count = ((depth - y_hole_offset )/((basic_tool_radius)*2 + tool_spacing)) - 1;
base_screw_hole_radius = 4.9/2; // approx. 3/16 inch


module tool_cylinders(hole_rad, hole_height){
  union(){
      for(i=[0:tool_count]){
        translate([basic_tool_radius + x_hole_offset , (i*(tool_spacing + basic_tool_radius*2)) + wall_thickness +  y_hole_offset + basic_tool_radius,0]){      
          cylinder(r = hole_rad, h = hole_height);
        }
      }
      for(i=[0:(tool_count -1)]){
        translate([3*basic_tool_radius + x_hole_offset, (i*(tool_spacing + basic_tool_radius*2)) + wall_thickness+ y_hole_offset + 2*basic_tool_radius,0]){      
          cylinder(r = hole_rad, h = hole_height);
        }
      }
    }
}

tool_pocket_height = 3;
endcap_size = width * 0.66;
rounding_radius = 1.25;
// the base
difference(){
  union(){   
    minkowski(){      
      cube([width, depth, base_thickness]);
      cylinder(r=rounding_radius, h=0.1, center = true);
    }
      
    translate([0,0,base_thickness]){
      difference(){
        tool_cylinders(basic_tool_radius * 0.65 + 1, tool_pocket_height);  
        tool_cylinders(basic_tool_radius * 0.65, tool_pocket_height);  
        
      }
    }
  }
  union(){
    translate([width - base_screw_hole_radius * 2, base_screw_hole_radius*2, -1]){
      cylinder(r =  base_screw_hole_radius, base_thickness  *2);
    }
    translate([width - base_screw_hole_radius * 2, depth  - base_screw_hole_radius*2, -1]){
      cylinder(r =  base_screw_hole_radius, base_thickness  *2);
    }
  }
}

  
module top_taper(){  
  poly_points = [
    [0,0],  
    [base_thickness*0.6,0],
    [base_thickness*0.6/2,width],
    [0,width]
  ];
  cutout_size = basic_tool_radius * 1.7;
  
    minkowski(){
      union(){
        difference(){
          linear_extrude(height=depth) polygon(poly_points); 
          
          
          translate([-1,width - cutout_size , 0]){
            cube([cutout_size , base_thickness  *3, cutout_size ]);         
          }
          
          translate([-1,width - cutout_size  , depth - cutout_size ]){
            cube([cutout_size, base_thickness  *3, cutout_size]);         
          }
        }
           
      }
      rotate([0,90,0]){
        cylinder(r=rounding_radius, h=0.1, center = true);
      }
    }
  
}

translate([0,0,height]){
  difference(){
    union(){
      rotate([-90,-90,0]){  
         color("grey") top_taper();//circle(r= 3, $fn = 3);    
      }
      translate([0,depth,0]){
        rotate([90,90,0]){  
           color("grey") top_taper();//circle(r= 3, $fn = 3);    
        }
      }
    }
    
    translate([0,0,-1 * base_thickness]){
      tool_cylinders(basic_tool_radius, base_thickness * 2);
    }
  } 
}



module endcap(){     
  difference(){
    minkowski(){      
      cube([endcap_size,wall_thickness - rounding_radius*2, height]);
      cylinder(r=rounding_radius, h=0.1, center = true);
    }
    
    translate([endcap_size + 2.75, wall_thickness * 2, height]){     
      rotate([90,0,0]){
        scale([1.28,height/(endcap_size/2.5)]) cylinder(r = endcap_size /3, h = wall_thickness * 3, $fn = 100);
        }
      }        
    translate([(endcap_size/2), wall_thickness  *2 , base_thickness * 2]){
      union(){     
      for(i = [1:9]){
        translate([0,0,i * 4 *base_screw_hole_radius]){
          rotate([90,0,0]){
            cylinder(r=base_screw_hole_radius, h = wall_thickness * 3);
            }
          }
        }        
      }
    }
  }
  
    
  
}

endcap();
translate([0,depth - wall_thickness + rounding_radius * 2,0]){
  endcap();
}

translate([wall_thickness - rounding_radius * 2, 0,0]){
  rotate([0,0,90]){  
    endcap();     
  }
  
  
}
translate([0, depth,0]){
    rotate([0,0,-90]){
      endcap();
    }
  }  

center_support_dim = x_hole_offset - 0.1 - rounding_radius*2;

translate([0,(depth)/2,0]){
  minkowski(){
    cube([center_support_dim, center_support_dim, height]);
    cylinder(r=rounding_radius, h=0.1, center = true);
  }
}
